@@ -7,9 +7,9 @@ from .state import BasicState
 from .atom import one, eof, eq, ne, oneOf, noneOf, pack, fail
 from .combinator import attempt, choice, choices, many, many1, manyTill, sep, sep1, sepTail, sep1Tail, skip, skip1, \
     between
-from .text import string, space
+from .text import string, space, digit
 
 __all__ = ["Parsec", "BasicState", "one", "eof", "eq", "ne", "oneOf", "noneOf",
            "pack", "fail", "attempt", "choice", "choices", "many", "many1", "manyTill",
            "between", "sep", "sep1", "sepTail", "sep1Tail", "skip", "skip1", "string",
-           "space", "ParsecEof", "ParsecError"]
+           "space", "digit", "ParsecEof", "ParsecError"]
