@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 # coding:utf-8
 
-from src.parsec import Parsec
-from src.parsec import ParsecError, ParsecEof
+from . import Parsec
+from . import ParsecError, ParsecEof
 
 
 @Parsec
@@ -38,9 +38,8 @@ def oneOf(data):
     @Parsec
     def call(st):
         re = st.next()
-        for item in data:
-            if re == item:
-                return re
+        if re in data:
+            return re
         else:
             raise ParsecError(st, "Expect one item of {0} but got {1}".format(data, re))
 
@@ -51,9 +50,8 @@ def noneOf(data):
     @Parsec
     def call(st):
         re = st.next()
-        for item in data:
-            if re == item:
-                raise ParsecError(st, "Expect none item of {0} but got {1}".format(data, re))
+        if re in data:
+            raise ParsecError(st, "Expect none item of {0} but got {1}".format(data, re))
         else:
             return re
 
